==> galileo-1.26.0.tar.gz: galileo-1.26.0/src/galileo/resources/api/prompts/get_template_version_projects_project_id_templates_template_id_versions_version_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.base_prompt_template_version_response import BasePromptTemplateVersionResponse
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(project_id: str, template_id: str, version: int) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.GET,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/templates/{template_id}/versions/{version}",
    }

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    if response.status_code == 200:
        return BasePromptTemplateVersionResponse.from_dict(response.json())

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(project_id=project_id, template_id=template_id, version=version)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[BasePromptTemplateVersionResponse, HTTPValidationError]
    """

    return sync_detailed(project_id=project_id, template_id=template_id, version=version, client=client).parsed


async def asyncio_detailed(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(project_id=project_id, template_id=template_id, version=version)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[BasePromptTemplateVersionResponse, HTTPValidationError]
    """

    return (
        await asyncio_detailed(project_id=project_id, template_id=template_id, version=version, client=client)
    ).parsed

==> galileo-1.29.1.tar.gz: galileo-1.29.1/src/galileo/resources/api/prompts/get_template_version_projects_project_id_templates_template_id_versions_version_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.base_prompt_template_version_response import BasePromptTemplateVersionResponse
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(project_id: str, template_id: str, version: int) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.GET,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/templates/{template_id}/versions/{version}",
    }

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    if response.status_code == 200:
        return BasePromptTemplateVersionResponse.from_dict(response.json())

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version.

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]
    """
    kwargs = _get_kwargs(project_id=project_id, template_id=template_id, version=version)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version.

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[BasePromptTemplateVersionResponse, HTTPValidationError]
    """
    return sync_detailed(project_id=project_id, template_id=template_id, version=version, client=client).parsed


async def asyncio_detailed(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version.

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]
    """
    kwargs = _get_kwargs(project_id=project_id, template_id=template_id, version=version)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, template_id: str, version: int, *, client: ApiClient
) -> Optional[Union[BasePromptTemplateVersionResponse, HTTPValidationError]]:
    """Get Template Version.

     Get a specific version of a prompt template.

    Parameters
    ----------
    template_id : UUID4
        Template ID.
    version : int
        Version number to fetch.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context)

    Returns
    -------
    BasePromptTemplateVersionResponse
        Prompt template version response.

    Args:
        project_id (str):
        template_id (str):
        version (int):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[BasePromptTemplateVersionResponse, HTTPValidationError]
    """
    return (
        await asyncio_detailed(project_id=project_id, template_id=template_id, version=version, client=client)
    ).parsed
